# -*- coding: utf-8 -*-
# Generated by Django 1.11.25 on 2019-10-03 11:45
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0003_auto_20191002_1425'),
    ]

    operations = [
        migrations.AddField(
            model_name='member',
            name='is_captain',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='project',
            name='team',
            field=models.ManyToManyField(through='djangoldp_project.Member', to=settings.AUTH_USER_MODEL),
        ),
    ]



from django.conf import settings
from django.db import models

from djangoldp.models import Model


class Customer(Model):
    name = models.CharField(max_length=255)
    address = models.CharField(max_length=255, blank=True)
    logo = models.URLField(blank=True, null=True)
    companyRegister = models.CharField(max_length=255, blank=True)
    firstName = models.CharField(max_length=255, blank=True)
    lastName = models.CharField(max_length=255, blank=True)
    role = models.CharField(max_length=255, blank=True)
    email = models.EmailField(blank=True)
    phone = models.CharField(max_length=255, blank=True)

    def __str__(self):
        return self.name


class BusinessProvider(Model):
    name = models.CharField(max_length=255)
    fee = models.PositiveIntegerField(default='0')

    def __str__(self):
        return self.name


def auto_increment_project_number():
  last_inc = Project.objects.all().order_by('id').last()
  if not last_inc:
    return 1
  return last_inc.number + 1


class Project(Model):
    name = models.CharField(max_length=255)
    description = models.TextField(blank=True)
    number = models.PositiveIntegerField(default=auto_increment_project_number, editable=False)
    creationDate = models.DateField(auto_now_add=True)
    customer = models.ForeignKey(Customer, on_delete=models.DO_NOTHING)  # WARN add import
    team = models.ManyToManyField(settings.AUTH_USER_MODEL, through='Member', blank=True)
    driveID = models.TextField(blank=True)
    businessProvider = models.ForeignKey(BusinessProvider, blank=True, null=True, on_delete=models.DO_NOTHING)
    jabberID = models.CharField(max_length=255, blank=True, null=True)
    jabberRoom = models.BooleanField(default=True)

    class Meta:
        nested_fields = ['team', 'customer', 'members']
        authenticated_perms = ['view', 'add', 'change', 'delete']
        rdf_type = 'hd:project'

    def __str__(self):
        return self.name


class Member(Model):
    project = models.ForeignKey(Project, on_delete=models.CASCADE, related_name='members')
    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE)
    name = models.CharField(max_length=255, blank=True)
    is_captain = models.BooleanField(default=False)

    class Meta:
        depth = 0

    def __str__(self):
        return self.name


Member._meta.container_path = "project-members/"



# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-10-02 14:25
from __future__ import unicode_literals

from django.db import migrations, models
import djangoldp_project.models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0002_auto_20190917_1122'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='number',
            field=models.PositiveIntegerField(default=djangoldp_project.models.auto_increment_project_number, editable=False),
        ),
    ]



from django.contrib import admin
from guardian.admin import GuardedModelAdmin
from .models import Project, Member, Customer, BusinessProvider


class TeamInline(admin.TabularInline):
    model = Member
    extra = 0


class ProjectAdmin(GuardedModelAdmin):
    inlines = [TeamInline]


admin.site.register(Project, ProjectAdmin)




from djangoldp.views import LDPViewSet
import requests

from djangoldp.views import LDPViewSet
from .models import Project


class ProjectViewSet(LDPViewSet):
    model = Project
    permission_classes = []
    nested_fields = ["members"]

    def update(self, request, *args, **kwargs):
        response = super().update(request, *args, **kwargs)
        requests.post("https://jabber.happy-dev.fr/happydev_muc_admin/",
                      json={"@context": "https://cdn.happy-dev.fr/owl/hdcontext.jsonld",
                            "@graph": [{"object": str(self.get_object().get_absolute_url()), "type": "Update"}]})
        return response


Project._meta.view_set = ProjectViewSet
